@@ -7,16 +7,14 @@ use warnings;
 use Carp;
 use Crypt::Cipher::RC6;
 use Crypt::Mode::CBC;
+use Crypt::Nettle::Cipher;
 use Crypt::Random qw( makerandom_octet );
 use Digest::MD5;
 use Mcrypt qw(ARCFOUR RIJNDAEL_128 RIJNDAEL_256);
 use Mcrypt qw(:MODES);
 use Mcrypt qw(:FUNCS);
 
-
-
-our $VERSION = '0.7.0';
-
+our $VERSION = '0.7.1';
 
 sub _EVP_BytesToKey($$$$$) 
 {
@@ -66,13 +64,13 @@ sub _initialize_cipher($$)
         "rc4-sha" => [Mcrypt::ARCFOUR,Mcrypt::STREAM,16,20],
         "aes-128-cbc"  => [Mcrypt::RIJNDAEL_128,Mcrypt::CBC,16,16],
         "aes-128-cfb"  => [Mcrypt::RIJNDAEL_128,Mcrypt::CFB,16,16],
-        "aes-128-ctr"  => [Mcrypt::RIJNDAEL_128,Mcrypt::CTR,16,16],
+        #"aes-128-ctr"  => [Mcrypt::RIJNDAEL_128,Mcrypt::CTR,16,16],
         "aes-128-ofb" => [Mcrypt::RIJNDAEL_128,Mcrypt::OFB,16,16],
         "aes-256-cbc"  => [Mcrypt::RIJNDAEL_256,Mcrypt::CBC,32,16],
         "aes-256-cfb"  => [Mcrypt::RIJNDAEL_256,Mcrypt::CFB,32,16],
-        "aes-256-ctr"  => [Mcrypt::RIJNDAEL_256,Mcrypt::CTR,32,16],
+        #"aes-256-ctr"  => [Mcrypt::RIJNDAEL_256,Mcrypt::CTR,32,16],
         "aes-256-ofb"  => [Mcrypt::RIJNDAEL_256,Mcrypt::OFB,32,16],
-        "rc6" => [undef,undef,16,16]
+        "rc6" => [undef,undef,8,16]
     );
     my $_method   = shift;
     my $_password = shift;
@@ -85,17 +83,16 @@ sub _initialize_cipher($$)
     if ( $_method eq 'rc6') 
     {
         $_key = Net::Shadowsocks::_EVP_BytesToKey( 16, 16, '', $_password, 1 );
-        $_iv = makerandom_octet( Length => %ciphers.{$_method}.[3] );
-        carp length($_key);
+        $_iv = makerandom_octet( Length => $ciphers{$_method}->[3] );
         $_encryptor = Crypt::Mode::CBC->new('RC6');
         $_decryptor = Crypt::Mode::CBC->new('RC6');
     }
-    elsif(!defined($_method))
+    elsif(defined($_method))
     {
-        $_encryptor = Mcrypt::mcrypt_load(%ciphers.{$_method}.[0],'',%ciphers.{$_method}.[1] , '' );
-        $_decryptor = Mcrypt::mcrypt_load(%ciphers.{$_method}.[0] ,'',%ciphers.{$_method}.[1], '' );
-        $_key = _EVP_BytesToKey( %ciphers.{$_method}.[2], %ciphers.{$_method}.[3], '', $_password, 1 );
-        $_iv = makerandom_octet( Length => %ciphers.{$_method}.[3] );
+        $_encryptor = Mcrypt::mcrypt_load($ciphers{$_method}->[0],'',$ciphers{$_method}->[1] , '' );
+        $_decryptor = Mcrypt::mcrypt_load($ciphers{$_method}->[0] ,'',$ciphers{$_method}->[1], '' );
+        $_key = _EVP_BytesToKey( $ciphers{$_method}->[2], $ciphers{$_method}->[3], '', $_password, 1 );
+        $_iv = makerandom_octet( Length => $ciphers{$_method}->[3] );
     }
     else
     {
@@ -106,34 +103,31 @@ sub _initialize_cipher($$)
         }
     return $_encryptor, $_decryptor, $_key, $_iv, $_nonce;
 }
-
-
 1;    # End of Net::Shadowsocks
 
-__END__
+ __END__
 
 =pod
-
-=encoding UTF-8
-
+=encoding utf8
 =head1 NAME
 
-Net::Shadowsocks - An asynchronous, non-blocking shadowsocks client and server module.
+Net::Shadowsocks
 
 =head1 VERSION
 
-version 0.7.0
+Version 0.7.1
 
 =head1 SYNOPSIS
 
     Shadowsocks protocol client and server module.
     
-    The following encryption methods are supported:
+The following shadowsocks encryption methods are supported:  
 
-rc4-md5 rc4-sha aes-128-cbc aes-128-cfb aes-128-ofb aes-256-cbc aes-256-cfb aes-256-ofb
-
-Experimental support of RC6 is also provided.
+rc4-md5 aes-128-cbc aes-128-cfb aes-128-ofb aes-256-cbc aes-256-cfb aes-256-ofb
 
+This module also supports rc4-sha and rc6 encryption methods which are not available
+from other shadowsocks implementations.
+ 
 Experimental server TCP Fast Open is also supported if available on Mac OS X and Linux. 
 
 Please also note that both the stock libmcrypt and stock Mcrypt module do not export CTR 
@@ -174,7 +168,7 @@ The following table shows TLS 1.2 cipher suite definitions and  equivalent
 encryptions methods used in this module: 
 
 TLS 1.2 Cipher Suite Definitions              Cipher                Encryption sMethod
-
+                                                                                                           
 TLS_RSA_WITH_RC4_128_MD5                RC4_128            RC4-MD5
 TLS_RSA_WITH_RC4_128_SHA                 RC4_128            RC4-SHA
 TLS_RSA_WITH_AES_128_CBC_SHA        AES_128_CBC    AES-128-CBC/CFB/OFB
@@ -193,12 +187,6 @@ to get it to work.
 
 Project website https://osdn.net/projects/ssperl/
 
-Net::Shadowsocks
-
-=head1 VERSION
-
-Version 0.7.0
-
 =head1 AUTHOR
 
 Li ZHOU, C<< <lzh at cpan.org> >>
@@ -215,6 +203,7 @@ You can find documentation for this module with the perldoc command.
 
 perldoc Net::Shadowsocks
 
+
 You can also look for information at:
 
 =over 4
@@ -237,8 +226,11 @@ L<http://search.cpan.org/dist/Net-Shadowsocks/>
 
 =back
 
+
 =head1 ACKNOWLEDGEMENTS
 
+
+
 =head1 LICENSE AND COPYRIGHT
 
 Copyright 2017 Li ZHOU.
@@ -279,15 +271,6 @@ CONTRIBUTOR WILL BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, OR
 CONSEQUENTIAL DAMAGES ARISING IN ANY WAY OUT OF THE USE OF THE PACKAGE,
 EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
-=head1 AUTHOR
-
-Li ZHOU <lzh@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2017 by Li ZHOU.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
 
 =cut
+
