@@ -16,10 +16,7 @@ package Net::Shadowsocks::Client;
     use Net::Shadowsocks qw(_EVP_BytesToKey _initialize_cipher);
     use Socket qw(IPPROTO_TCP MSG_FASTOPEN);
 
-
-our $VERSION = '0.7.0';
-
-
+    our $VERSION = '0.7.1';
     sub new($$$$$$) 
     {
         my $_osname = $Config{osname};
@@ -118,7 +115,6 @@ our $VERSION = '0.7.0';
                                         return;
                                     }
                                     $addr_to_send = substr( $client_buffer, 3 );
-
                                     if ( !defined( $self->{local_address} ) ) 
                                     {
                                         $self->{local_address} = 'localhost';
@@ -185,13 +181,12 @@ our $VERSION = '0.7.0';
                                                         my $decrypt_rc4_key = substr($sha->digest(),0,16);
                                                         Mcrypt::mcrypt_init($decryptor,$decrypt_rc4_key,'' );
                                                         }
-                                                        else
+                                                        elsif($self->{method} ne'rc6')
                                                         {
-                                                            
                                                             Mcrypt::mcrypt_init($decryptor,$key,$server_iv );
                                                             }
                                                 }
-                                                if ($self->{method} eq 'rc5')
+                                                if ($self->{method} eq 'rc6')
                                                 {
                                                     $decrypteddata = $decryptor->decrypt($incomingdata,$key,$server_iv);
                                                     }
@@ -300,41 +295,34 @@ our $VERSION = '0.7.0';
         return $self;
     }
     1;    # End of Net::Shadowsocks::Client
-
-__END__
-
-=pod
-
-=encoding UTF-8
-
-=head1 NAME
-
-Net::Shadowsocks::Client - Shadowsocks protocol client module.
-
-=head1 VERSION
-
-version 0.7.0
-
-=head1 SYNOPSIS
-
-    Shadowsocks protocol client module.
+ 
+  __END__
     
-    The following encryption methods are supported:
-
-rc4-md5 rc4-sha aes-128-cbc aes-128-cfb aes-128-ofb aes-256-cbc aes-256-cfb aes-256-ofb
-
-Experimental support of RC6 is also provided.
-
-Please also note that both the stock libmcrypt and stock Mcrypt module do not export CTR 
-mode, So the aes-128-ctr and aes-256-ctr method will not work out of box. You have to use this 
-  patched version of libmcrypt and Libmcrypt module from https://osdn.net/projects/mcrypt/
-to get it to work.  
+=pod
+=encoding utf8
+=head1 NAME
 
 Net::Shadowsocks::Client
 
 =head1 VERSION
 
-Version 0.7.0
+Version 0.7.1
+
+=head1 SYNOPSIS
+
+    Shadowsocks protocol client module.
+
+The following shadowsocks encryption methods are supported:  
+
+rc4-md5 aes-128-cbc aes-128-cfb aes-128-ofb aes-256-cbc aes-256-cfb aes-256-ofb
+
+This module also supports rc4-sha and rc6 encryption methods which are not available
+from other shadowsocks implementations.
+
+Please also note that both the stock libmcrypt and stock Mcrypt module do not export CTR 
+mode, So the aes-128-ctr and aes-256-ctr method will not work out of box. You have to use this 
+  patched version of libmcrypt and Libmcrypt module from https://osdn.net/projects/mcrypt/
+to get it to work.  
 
 =head1 METHODS
 
@@ -364,13 +352,86 @@ Version 0.7.0
 
 =head1 AUTHOR
 
-Li ZHOU <lzh@cpan.org>
+Li ZHOU, C<< <lzh at cpan.org> >>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 BUGS
 
-This software is copyright (c) 2017 by Li ZHOU.
+Please report any bugs or feature requests to C<bug-net-shadowsocks at rt.cpan.org>, or through
+the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Net-Shadowsocks>.  I will be notified, and then you'll
+automatically be notified of progress on your bug as I make changes.
 
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
+=head1 SUPPORT
 
-=cut
+You can find documentation for this module with the perldoc command.
+
+perldoc Net::Shadowsocks
+
+
+You can also look for information at:
+
+=over 4
+
+=item * RT: CPAN's request tracker (report bugs here)
+
+L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Net-Shadowsocks>
+
+=item * AnnoCPAN: Annotated CPAN documentation
+
+L<http://annocpan.org/dist/Net-Shadowsocks>
+
+=item * CPAN Ratings
+
+L<http://cpanratings.perl.org/d/Net-Shadowsocks>
+
+=item * Search CPAN
+
+L<http://search.cpan.org/dist/Net-Shadowsocks/>
+
+=back
+
+
+=head1 ACKNOWLEDGEMENTS
+
+
+
+=head1 LICENSE AND COPYRIGHT
+
+Copyright 2017 Li ZHOU.
+
+This program is free software; you can redistribute it and/or modify it
+under the terms of the the Artistic License (2.0). You may obtain a
+copy of the full license at:
+
+L<http://www.perlfoundation.org/artistic_license_2_0>
+
+Any use, modification, and distribution of the Standard or Modified
+Versions is governed by this Artistic License. By using, modifying or
+distributing the Package, you accept this license. Do not use, modify,
+or distribute the Package, if you do not accept this license.
+
+If your Modified Version has been derived from a Modified Version made
+by someone other than you, you are nevertheless required to ensure that
+your Modified Version complies with the requirements of this license.
+
+This license does not grant you the right to use any trademark, service
+mark, tradename, or logo of the Copyright Holder.
+
+This license includes the non-exclusive, worldwide, free-of-charge
+patent license to make, have made, use, offer to sell, sell, import and
+otherwise transfer the Package with respect to any patent claims
+licensable by the Copyright Holder that are necessarily infringed by the
+Package. If you institute patent litigation (including a cross-claim or
+counterclaim) against any party alleging that the Package constitutes
+direct or contributory patent infringement, then this Artistic License
+to you shall terminate on the date that such litigation is filed.
+
+Disclaimer of Warranty: THE PACKAGE IS PROVIDED BY THE COPYRIGHT HOLDER
+AND CONTRIBUTORS " AS IS ' AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES.
+THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
+PURPOSE, OR NON-INFRINGEMENT ARE DISCLAIMED TO THE EXTENT PERMITTED BY
+YOUR LOCAL LAW. UNLESS REQUIRED BY LAW, NO COPYRIGHT HOLDER OR
+CONTRIBUTOR WILL BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, OR
+CONSEQUENTIAL DAMAGES ARISING IN ANY WAY OUT OF THE USE OF THE PACKAGE,
+EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+
+=cut
\ No newline at end of file
